pub struct ResolveJob {
pub original_tir: AnyTir,
pub args: ArgMap,
pub compiler: Value,
pub round: usize,
pub last_eval: Option<CompiledTx>,
pub converged: bool,
pub log: Vec<ResolveLogEntry>,
pub input_queries: Vec<QueryResolution>,
pub input_pool: Option<HashMap<UtxoRef, Utxo>>,
}Fields
original_tir: AnyTirargs: ArgMapcompiler: Valueround: usizelast_eval: Option<CompiledTx>converged: boollog: Vec<ResolveLogEntry>input_queries: Vec<QueryResolution>input_pool: Option<HashMap<UtxoRef, Utxo>>Implementations
Sourceimpl ResolveJob
impl ResolveJob
Sourcepub fn approximate_queries(&mut self)
pub fn approximate_queries(&mut self)
For each query, filter the pool by hard constraints, rank by closeness to the target asset composition, then filter by aggregate constraints.
Sourceimpl ResolveJob
impl ResolveJob
Sourcepub fn assign_all(&mut self) -> Result<(), Error>
pub fn assign_all(&mut self) -> Result<(), Error>
Given queries with their ranked candidates (from the approximation stage), find an allocation that satisfies all queries simultaneously using greedy assignment. Returns an error if any query cannot be resolved.
Sourceimpl ResolveJob
impl ResolveJob
Sourceimpl ResolveJob
impl ResolveJob
Sourceimpl ResolveJob
impl ResolveJob
pub fn new(tx: AnyTir, args: ArgMap) -> Self
pub fn record(&mut self, event: ResolveLog)
pub fn resolved_tir(&self) -> &AnyTir
pub fn set_input_queries(&mut self, queries: Vec<(String, CanonicalQuery)>)
pub fn pool_refs(&self) -> Vec<UtxoRef>
pub fn to_input_map(&self) -> BTreeMap<String, UtxoSet>
pub async fn execute<C, S>( &mut self, compiler: &mut C, utxos: &S, max_optimize_rounds: usize, ) -> Result<CompiledTx, Error>